/***************************************************************
 *
 * Copyright (C) 1990-2007, Condor Team, Computer Sciences Department,
 * University of Wisconsin-Madison, WI.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 * 
 *    http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ***************************************************************/


#ifndef CONDOR_NETDB_H
#define CONDOR_NETDB_H

#include "condor_common.h"
#include "condor_socket_types.h"

#if defined(__cplusplus)
extern "C" {
#endif


// do not use gethostbyname and gethostbyaddr
// use resolve_hsotname, get_hostname instead

//struct hostent *
//condor_gethostbyname(const char *name);
//
//struct hostent *
//condor_gethostbyaddr(const char *addr, SOCKET_LENGTH_TYPE len, int type);

int
condor_gethostname(char *name, size_t namelen);

#if defined(__cplusplus)
}
#endif

#endif
